@@ -1,13 +1,14 @@
+from typing import Type
+
 from django.http import Http404
 from django.utils.translation import gettext as _
 from rest_framework import serializers
-from rest_framework.decorators import api_view, permission_classes
+from rest_framework.request import Request
+from rest_framework.response import Response
+from rest_framework.serializers import Serializer
 
 from rest_registration.api.serializers import PasswordConfirmSerializerMixin
-from rest_registration.decorators import (
-    api_view_serializer_class,
-    api_view_serializer_class_getter
-)
+from rest_registration.api.views.base import BaseAPIView
 from rest_registration.exceptions import UserNotFound
 from rest_registration.settings import registration_settings
 from rest_registration.signers.reset_password import ResetPasswordSigner
@@ -21,33 +22,37 @@ from rest_registration.utils.validation import (
 from rest_registration.utils.verification import verify_signer_or_bad_request
 
 
-@api_view_serializer_class_getter(
-    lambda: registration_settings.SEND_RESET_PASSWORD_LINK_SERIALIZER_CLASS)
-@api_view(['POST'])
-@permission_classes(registration_settings.NOT_AUTHENTICATED_PERMISSION_CLASSES)
-def send_reset_password_link(request):
-    '''
-    Send email with reset password link.
-    '''
-    if not registration_settings.RESET_PASSWORD_VERIFICATION_ENABLED:
-        raise Http404()
-    serializer_class = registration_settings.SEND_RESET_PASSWORD_LINK_SERIALIZER_CLASS
-    serializer = serializer_class(data=request.data, context={'request': request})
-    serializer.is_valid(raise_exception=True)
-    if registration_settings.RESET_PASSWORD_FAIL_WHEN_USER_NOT_FOUND:
-        success_message = _("Reset link sent")
-    else:
-        success_message = _("Reset link sent if the user exists in database")
-    user_finder = registration_settings.SEND_RESET_PASSWORD_LINK_USER_FINDER
-    try:
-        user = user_finder(serializer.validated_data, serializer=serializer)
-    except UserNotFound:
+class SendResetPasswordLinkView(BaseAPIView):
+    permission_classes = registration_settings.NOT_AUTHENTICATED_PERMISSION_CLASSES
+
+    def post(self, request: Request) -> Response:
+        '''
+        Send email with reset password link.
+        '''
+        if not registration_settings.RESET_PASSWORD_VERIFICATION_ENABLED:
+            raise Http404()
+        serializer = self.get_serializer(data=request.data)
+        serializer.is_valid(raise_exception=True)
         if registration_settings.RESET_PASSWORD_FAIL_WHEN_USER_NOT_FOUND:
-            raise
+            success_message = _("Reset link sent")
+        else:
+            success_message = _("Reset link sent if the user exists in database")
+        user_finder = registration_settings.SEND_RESET_PASSWORD_LINK_USER_FINDER
+        try:
+            user = user_finder(serializer.validated_data, serializer=serializer)
+        except UserNotFound:
+            if registration_settings.RESET_PASSWORD_FAIL_WHEN_USER_NOT_FOUND:
+                raise
+            return get_ok_response(success_message)
+        email_sender = registration_settings.RESET_PASSWORD_VERIFICATION_EMAIL_SENDER
+        email_sender(request, user)
         return get_ok_response(success_message)
-    email_sender = registration_settings.RESET_PASSWORD_VERIFICATION_EMAIL_SENDER
-    email_sender(request, user)
-    return get_ok_response(success_message)
+
+    def get_serializer_class(self) -> Type[Serializer]:
+        return registration_settings.SEND_RESET_PASSWORD_LINK_SERIALIZER_CLASS
+
+
+send_reset_password_link = SendResetPasswordLinkView.as_view()
 
 
 class ResetPasswordSerializer(  # pylint: disable=abstract-method
@@ -71,15 +76,22 @@ class ResetPasswordSerializer(  # pylint: disable=abstract-method
         return attrs
 
 
-@api_view_serializer_class(ResetPasswordSerializer)
-@api_view(['POST'])
-@permission_classes(registration_settings.NOT_AUTHENTICATED_PERMISSION_CLASSES)
-def reset_password(request):
-    '''
-    Reset password, given the signature and timestamp from the link.
-    '''
-    process_reset_password_data(request.data, serializer_context={'request': request})
-    return get_ok_response(_("Reset password successful"))
+class ResetPassordView(BaseAPIView):
+    serializer_class = ResetPasswordSerializer
+    permission_classes = registration_settings.NOT_AUTHENTICATED_PERMISSION_CLASSES
+
+    def post(self, request: Request) -> Response:
+        '''
+        Reset password, given the signature and timestamp from the link.
+        '''
+        process_reset_password_data(
+            request.data,
+            serializer_context=self.get_serializer_context(),
+        )
+        return get_ok_response(_("Reset password successful"))
+
+
+reset_password = ResetPassordView.as_view()
 
 
 def process_reset_password_data(input_data, serializer_context=None):
