@@ -1,6 +1,8 @@
 from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:
+    from django_stubs_ext import StrOrPromise
+
     # mypy uses typing_extensions by default (Py 3.8); when importing from typing
     # one will get the following error message in mypy:
     #
@@ -13,3 +15,4 @@ else:
         from typing import Literal
     except ImportError:
         from typing_extensions import Literal  # noqa: F401
+    StrOrPromise = str
