@@ -29,24 +29,14 @@ _ModelT = TypeVar('_ModelT', bound=Model)
 if TYPE_CHECKING:
     from typing import Optional
     from django.contrib.auth.base_user import AbstractBaseUser
+    from django.contrib.contenttypes.fields import GenericForeignKey
     from django.db.models import Field, ForeignObjectRel
 
-    UserField = Union['Field', 'ForeignObjectRel']
+    UserField = Union[Field[Any, Any], ForeignObjectRel, GenericForeignKey]
 
 
 def authenticate_by_login_data(
         data: Dict[str, Any], **kwargs: Any) -> 'AbstractBaseUser':
-    serializer = kwargs.get('serializer')
-    if serializer:
-        # TODO: Issue #114 - remove code supporting deprecated behavior
-        get_authenticated_user = getattr(
-            serializer, 'get_authenticated_user', None)
-        if callable(get_authenticated_user):
-            user = get_authenticated_user()  # type: Optional[AbstractBaseUser]
-            if not user:
-                raise UserNotFound()
-            return user
-
     login_field_names = get_user_login_field_names()
     username_field_name = get_username_field_name()
     password = data.get('password')
@@ -114,15 +104,6 @@ def find_user_by_by_send_reset_password_link_data(
     Return user if matching given criteria (login fields / e-mail).
     Return ``None`` otherwise.
     """
-    serializer = kwargs.get('serializer')
-    if serializer:
-        # TODO: Issue #114 - remove code supporting deprecated behavior
-        get_user_or_none = getattr(serializer, 'get_user_or_none', None)
-        if callable(get_user_or_none):
-            user = get_user_or_none()  # type: Optional[AbstractBaseUser]
-            if not user:
-                raise UserNotFound()
-            return user
     login_field_names = get_user_login_field_names()
     finder_tests = [('login', login_field_names)]
     finder_tests.extend((f, [f]) for f in login_field_names)
@@ -179,8 +160,7 @@ def get_user_by_lookup_dict(
         if default is DefaultValues.RAISE_EXCEPTION:
             raise UserNotFound() from None
         return default
-    else:
-        return user
+    return user
 
 
 def get_user_field_obj(name: str) -> 'UserField':
